==> servicemix-wsn2005-3.3.0.5-fuse-sources.jar: org/apache/servicemix/wsn/jaxws/NotificationProducerServiceService.java <==

package org.apache.servicemix.wsn.jaxws;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;

@WebServiceClient(targetNamespace = "http://servicemix.apache.org/wsn/jaxws", name = "NotificationProducerService", wsdlLocation = "file:/home/bsnyder/src/iona/servicemix/tags/servicemix-3.3.0.5-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl")
public class NotificationProducerServiceService
    extends Service
{

    private static Map ports = new HashMap();
    public static Class NotificationProducer = org.apache.servicemix.wsn.jaxws.NotificationProducer.class;

    static {
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationProducer);
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationProducerServiceLocalPort"), NotificationProducer);
    }

    public NotificationProducerServiceService()
        throws MalformedURLException
    {
        super(new URL("file:/home/bsnyder/src/iona/servicemix/tags/servicemix-3.3.0.5-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl"), new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationProducerService"));
    }

    public static Map getPortClassMap() {
        return ports;
    }

    @WebEndpoint(name = "JBI")
    public org.apache.servicemix.wsn.jaxws.NotificationProducer getJBI() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationProducer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationProducer));
    }

    @WebEndpoint(name = "NotificationProducerServiceLocalPort")
    public org.apache.servicemix.wsn.jaxws.NotificationProducer getNotificationProducerServiceLocalPort() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationProducer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationProducerServiceLocalPort"), NotificationProducer));
    }

}

==> servicemix-wsn2005-3.3.0.8-fuse-sources.jar: org/apache/servicemix/wsn/jaxws/NotificationProducerServiceService.java <==

package org.apache.servicemix.wsn.jaxws;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;

@WebServiceClient(targetNamespace = "http://servicemix.apache.org/wsn/jaxws", name = "NotificationProducerService", wsdlLocation = "file:/x1/janstey/servicemix-3.3.0-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl")
public class NotificationProducerServiceService
    extends Service
{

    private static Map ports = new HashMap();
    public static Class NotificationProducer = org.apache.servicemix.wsn.jaxws.NotificationProducer.class;

    static {
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationProducer);
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationProducerServiceLocalPort"), NotificationProducer);
    }

    public NotificationProducerServiceService()
        throws MalformedURLException
    {
        super(new URL("file:/x1/janstey/servicemix-3.3.0-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl"), new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationProducerService"));
    }

    public static Map getPortClassMap() {
        return ports;
    }

    @WebEndpoint(name = "JBI")
    public org.apache.servicemix.wsn.jaxws.NotificationProducer getJBI() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationProducer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationProducer));
    }

    @WebEndpoint(name = "NotificationProducerServiceLocalPort")
    public org.apache.servicemix.wsn.jaxws.NotificationProducer getNotificationProducerServiceLocalPort() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationProducer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationProducerServiceLocalPort"), NotificationProducer));
    }

}
